# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# perl_vendorlib/perl_vendorarch not defined by default prior to F-2
%{!?perl_vendorlib: %global perl_vendorlib %(eval "`perl -V:installvendorlib`"; echo $installvendorlib)}

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)

# Select the appropriate system speller
%if %(perl -e 'print (($] >= 5.010000) ? 1 : 0);')
%global speller hunspell
%else
%global speller aspell
%endif

# Old hunspell versions need a workaround
%global hunspell_version %((hunspell -v 2>/dev/null || echo 1.2.8@) | awk '{ print substr($NF, 1, length($NF)-1); exit }')

Name:		perl-Test-Spelling
Version:	0.15
Release:	1.%{__distinit}%{__distvers}
Summary:	Check for spelling errors in POD files
Group:		Development/Libraries
License:	GPL+ or Artistic
URL:		http://search.cpan.org/dist/Test-Spelling/
Source0:	http://search.cpan.org/CPAN/authors/id/S/SA/SARTAK/Test-Spelling-%{version}.tar.gz
Patch0:		Test-Spelling-0.13-hunspell.patch
Patch1:		Test-Spelling-0.14-C-locale.patch
Patch2:		Test-Spelling-0.15-old-perl.patch
Patch3:		Test-Spelling-0.15-old-Test::More.patch
PAtch4:		Test-Spelling-0.15-stopwords.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
BuildRequires:	%{speller}
BuildRequires:	%{speller}-en%(perl -e 'print "-gb" if $] < 5.008001;')
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Pod::Spell) >= 1.01
BuildRequires:	perl(Test::Pod)
BuildRequires:	perl(Test::Tester)
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
Requires:	%{speller}

%description
"Test::Spelling" lets you check the spelling of a POD file, and report
its results in standard "Test::Simple" fashion.

%prep
%setup -q -n Test-Spelling-%{version}

# Patch for hunspell if necessary
%if "%{speller}" == "hunspell"
%patch0 -p1
%endif

# hunspell in F-9 and F-10 doesn't treat "C" locale as "en_US"
# so force it to do so
%if %(perl -e 'print ((%{hunspell_version} lt 1.2.8) ? 1 : 0);')
%patch1 -p1
%endif

# The module does not really need perl 5.8.3
%if %(perl -e 'print (($] < 5.008003) ? 1 : 0);')
%patch2 -p1
%endif

# We need to patch the test suite if we have an old version of Test::More
%if %{old_test_more}
%patch3 -p1
%endif

# Some old distributions need extra stopwords due to poor dictionary coverage
%patch4 -p1

# Force the author test to run too
mkdir inc/.author

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install PERL_INSTALL_ROOT=%{buildroot}
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -depth -type d -exec rmdir {} \; 2>/dev/null
%{_fixperms} %{buildroot}

%check
make test

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%doc Changes README
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Spelling.3pm*

%changelog
* Tue Aug 23 2011 Paul Howarth <paul@city-fan.org> - 0.15-1
- Update to 0.15:
  - Begin adding actual tests (hilariously, adding the suggested t/pod-spell.t
    to this dist to test itself found a typo: "stopwards")
- BR: perl(Test::Tester) and a suitable English dictionary
- Add patch to support building with perl < 5.8.3
- Add patch to support building with Test::More < 0.88
- Add patch for extra stopwords on old distributions

* Mon Aug  8 2011 Paul Howarth <paul@city-fan.org> - 0.14-3
- Add hack for hunspell < 1.2.8, which doesn't treat the "C" locale as "en_US"
  by default

* Sat Jul  2 2011 Paul Howarth <paul@city-fan.org> - 0.14-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May 27 2011 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14:
  - Fix an error when using add_stopwords("constant","strings") (CPAN RT#68471)

* Wed Apr 27 2011 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13:
  - Make alternatives checking more robust by reading the spellchecker's STDERR

* Tue Apr 26 2011 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12:
  - Best Practical has taken over maintainership of this module
  - Try various spellcheck programs instead of hardcoding the ancient `spell`
    (CPAN RT#56483)
  - Remove temporary files more aggressively (CPAN RT#41586)
  - Fixed by not creating them at all - instead we now use IPC::Open3
  - Remove suggestion to use broken `aspell -l` (CPAN RT#28967)
  - Add set_pod_file_filter for skipping translations, etc. (CPAN RT#63755)
  - Skip tests in all_pod_files_spelling_ok if there is no working spellchecker
  - Provide a has_working_spellchecker so you can skip your own tests if
    there's no working spellchecker
  - Switch to Module::Install
  - Rewrite and modernize a lot of the documentation
  - Decruftify code, such as by using Exporter and lexical filehandles
  - Support .plx files
- This release by SARTAK -> update source URL
- Rewrite hunspell patch to just favour hunspell over aspell
- Drop File::Temp requirement, so we can run on RHL-9/RHEL-3 now
- Nobody else likes macros for commands

* Thu Jun 24 2010 Paul Howarth <paul@city-fan.org> - 0.11-9
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 17 2010 Paul Howarth <paul@city-fan.org> - 0.11-8
- Fix dist tag for RHEL-6 Beta

* Fri Jan 29 2010 Paul Howarth <paul@city-fan.org> - 0.11-7
- Patch to use hunspell rather than aspell with perl 5.10 onwards
  (F-9 onwards - #508643)
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Thu Nov 26 2009 Paul Howarth <paul@city-fan.org> - 0.11-6
- Import from Fedora
- Buildreq File::Temp >= 0.14, needed for OO interface used in this module

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.11-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.11-3
- Rebuild for perl 5.10 (again)

* Sun Jan 13 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.11-2
- Rebuild for new perl

* Tue Dec 19 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.11-1
- First build
